package uoa.tsco033.evolisa;

import android.app.AlertDialog;
import android.app.Dialog;
import android.app.DialogFragment;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.Toast;

public class DialogFragmentSaveImage extends DialogFragment
{
	public interface onSaveCompleteListener
	{
		void displaySaveMessage(String message);
	}
		
	private EditText filenameEditText;
	private CheckBox svgCheckBox;
	private CheckBox jpegCheckBox;
	private CheckBox pngCheckBox;
	private Button saveButton;
	private Button cancelButton;
	
	private DNADrawing drawingToSave;
	
	private int height;
	private int width;
	
	public DialogFragmentSaveImage()
	{
	}
	
	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState)
	{
		View view = inflater.inflate(R.layout.dialog_saveimage, container);
		
		getDialog().setTitle(R.string.title_dialog_saveimage);
		
		filenameEditText = (EditText) view.findViewById(R.id.saveimage_edittext_filename);
		svgCheckBox = (CheckBox) view.findViewById(R.id.saveimage_checkbox_svg);
		jpegCheckBox = (CheckBox) view.findViewById(R.id.saveimage_checkbox_jpeg);
		pngCheckBox = (CheckBox) view.findViewById(R.id.saveimage_checkbox_png);
		saveButton = (Button) view.findViewById(R.id.saveimage_button_save);
		cancelButton = (Button) view.findViewById(R.id.saveimage_button_cancel);
				
		drawingToSave = getArguments().getParcelable("drawing");
		
		height = getArguments().getInt("height");
		width = getArguments().getInt("width");
		
		saveButton.setOnClickListener(new View.OnClickListener()
		{			
			@Override
			public void onClick(View v)
			{				
				StringBuilder messageText = new StringBuilder();
				
				if (svgCheckBox.isChecked())
				{
					messageText.append(Tools.writeToSVGFile(drawingToSave, filenameEditText.getText().toString()));
				}
				if (jpegCheckBox.isChecked())
				{
					if (messageText.length() > 0) { messageText.append("\n"); }
					messageText.append(Tools.writeToJPEGFile(DialogFragmentSaveImage.this.getActivity(), drawingToSave, height, width, filenameEditText.getText().toString()));
				}
				if (pngCheckBox.isChecked())
				{
					if (messageText.length() > 0) { messageText.append("\n"); }
					messageText.append(Tools.writeToPNGFile(DialogFragmentSaveImage.this.getActivity(), drawingToSave, height, width, filenameEditText.getText().toString()));
				}				
			
				DialogFragmentSaveImage.this.dismiss();
				
				((ActivityGenerateImage) DialogFragmentSaveImage.this.getActivity()).displaySaveMessage(messageText.toString());
			}
		});
		
		cancelButton.setOnClickListener(new View.OnClickListener()
		{			
			@Override
			public void onClick(View v)
			{
				DialogFragmentSaveImage.this.dismiss();
			}
		});
		
		svgCheckBox.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked)
			{
				setButtonStates();				
			}	
		});
		
		jpegCheckBox.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked)
			{
				setButtonStates();
			}		
		});
		
		pngCheckBox.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked)
			{
				setButtonStates();
			}		
		});
		
		filenameEditText.addTextChangedListener(new TextWatcher() {
			@Override
			public void afterTextChanged(Editable arg0)	{}

			@Override
			public void beforeTextChanged(CharSequence arg0, int arg1, int arg2, int arg3) {}

			@Override
			public void onTextChanged(CharSequence arg0, int arg1, int arg2, int arg3)
			{
				setButtonStates();
			}			
		});
		
		setButtonStates();
		
		return view;
	}
	
	private void setButtonStates()
	{
		if ((filenameEditText.getText().toString().length() > 0) && (jpegCheckBox.isChecked() || svgCheckBox.isChecked() || pngCheckBox.isChecked()))
		{
			saveButton.setEnabled(true);
		}
		else
		{
			saveButton.setEnabled(false);
		}
	}
}
