/**	Author: Travis Scott (ID 1554515)
 * 	Date: 14/12/2012
 */

package uoa.tsco033.evolisa;

import java.util.ArrayList;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.graphics.Path;
import android.graphics.Point;

/**This class renders a list of DNA Polygons to a canvas object 
 * @author tsco033
 */
public class Renderer
{
	//---------- Setup ----------//
	
	public static void render(DNADrawing drawing, Canvas canvas, int scale)
	{
		// Set canvas to white
		canvas.drawColor(Color.WHITE);
		
		// Loop through each background polygon and draw it to screen
		for (DNAPolygon polygon : drawing.getBackgroundPolygons())
		{
			canvas.drawPath(getPath(polygon, scale), getColor(polygon));
		}
		// Loop through each active polygon and draw it to screen
		for (DNAPolygon polygon : drawing.getMutablePolygons())
		{
			canvas.drawPath(getPath(polygon, scale), getColor(polygon));
		}
		// Loop through each foreground polygon and draw it to screen
		for (DNAPolygon polygon : drawing.getForegroundPolygons())
		{
			canvas.drawPath(getPath(polygon, scale), getColor(polygon));
		}
	}

	//---------- Methods ----------//
	
	/**Returns a paint object (effectively a colour) 
	 * @param polygon
	 * @return Paint 
	 */
	private static Paint getColor(DNAPolygon polygon)
	{
		// Create a new paint object
		Paint color = new Paint();
		
		// Get ARGB values from polygon
		int[] colors = polygon.getColor();
		
		// Set the color
		color.setColor(Color.argb(colors[0], colors[1], colors[2], colors[3]));
		
		// Set paint object to fill objects
		color.setStyle(Style.FILL);
		
		return color;
	}

	/**Returns a path (connection between points defining a polygon) 
	 * for a given DNAPolygon object
	 * @param polygon
	 * @param scale
	 * @return
	 */
	private static Path getPath(DNAPolygon polygon, int scale)
	{
		// Extract the points defining the polygon
		ArrayList<DNAPoint> sourcePoints = polygon.getPoints();
		
		// Create an array from the list
		Point[] drawPoints = new Point[sourcePoints.size()];
		
		int i = 0;
		
		// Loop through each point in the list
		for (DNAPoint sourcePoint : sourcePoints)
		{
			// Scale the point in the list and add it to the array
			drawPoints[i] = new Point(sourcePoint.getX() * scale, sourcePoint.getY() * scale);
			i++;
		}

		// Create a new path object
		Path path = new Path();
		
		// Move to the location of the first point (start of the path)
		path.moveTo(drawPoints[0].x, drawPoints[0].y);
		
		// Loop through each point, starting with the second
		for (i = 1; i < sourcePoints.size(); i++)
		{
			// Draw the path to that point
			path.lineTo(drawPoints[i].x, drawPoints[i].y);
		}
		
		// Draw back to the starting point
		path.lineTo(drawPoints[0].x, drawPoints[0].y);
		
		// TODO Move to last point and then loop through normally?
		
		return path;
	}
}
